from typing import Literal

BackdropBlur = Literal[
    'none',
    'sm',
    '',
    'md',
    'lg',
    'xl',
    '2xl',
    '3xl',
]
